"""Object constraints."""
from jsonvl._utilities.venum import Venum


class ObjectConstraints(Venum):
    """Constraints applied to object types."""

    pass
